Module libpulse_sys::context::introspect
source · Expand description
Routines for daemon introspection.
Structs
pa_card_profile_infoDeprecated
Stores information about a specific profile of a card.
Stores information about clients.
Please note that this structure can be extended as part of evolutionary API updates at any time
in any new release.
Memory block statistics.