Struct libpulse_sys::context::introspect::pa_client_info [−][src]
#[repr(C)]pub struct pa_client_info {
pub index: u32,
pub name: *const c_char,
pub owner_module: u32,
pub driver: *const c_char,
pub proplist: *mut pa_proplist,
}Expand description
Stores information about clients.
Please note that this structure can be extended as part of evolutionary API updates at any time in any new release.
Fields
index: u32Index of this client.
name: *const c_charName of this client.
owner_module: u32Index of the owning module, or PA_INVALID_INDEX.
driver: *const c_charDriver name.
proplist: *mut pa_proplistProperty list.