Module libpulse_sys::context::subscribe::event_facilities
source · Expand description
Possible facility variants that could be extracted from an event type.
Constants
Global server change, only occurring with a change operation.