#[repr(C)]
pub struct pa_timing_info {Show 13 fields
pub timestamp: timeval,
pub synchronized_clocks: i32,
pub sink_usec: pa_usec_t,
pub source_usec: pa_usec_t,
pub transport_usec: pa_usec_t,
pub playing: i32,
pub write_index_corrupt: i32,
pub write_index: i64,
pub read_index_corrupt: i32,
pub read_index: i64,
pub configured_sink_usec: pa_usec_t,
pub configured_source_usec: pa_usec_t,
pub since_underrun: i64,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.