pa_direction_t

Type Alias pa_direction_t 

pub type pa_direction_t = i32;
Direction bitfield.

While we currently do not expose anything bidirectional, one should test against the bit instead of the value because we might add bidirectional stuff in the future.