Module libpulse_sys::format

source ·
Utility functions for handling a stream or sink format.

Structs

Represents the format of data provided in a stream or processed by a sink.

Enums

Represents the type of value of a property.

Constants

The maximum length of strings returned by pa_format_info_snprint. Please note that this value can change with any release without warning and without being considered API or ABI breakage. You should not use this definition anywhere where it might become part of an ABI.

Functions