#[repr(C)]
pub enum pa_operation_state_t {
Running,
Done,
Cancelled,
}Variants
Running
The operation is still running.
Done
The operation has completed.
Cancelled
The operation has been cancelled. Operations may get cancelled by the application, or as a result of the context getting disconnected while the operation is pending.