Module libpulse_sys::sample

source ·
Constants and routines for sample type handling.

Structs

A sample format and attribute specification

Enums

Sample format

Constants

The maximum length of strings returned by pa_bytes_snprint. Please note that this value can change with any release without warning and without being considered API or ABI breakage. You should not use this definition anywhere where it might become part of an ABI.
Maximum number of allowed channels
Maximum allowed sample rate
The maximum length of strings returned by pa_sample_spec_snprint. Please note that this value can change with any release without warning and without being considered API or ABI breakage. You should not use this definition anywhere where it might become part of an ABI.

Functions

Type Definitions

Type for usec specifications (unsigned). Always 64 bit.