Enum libpulse_sys::stream::pa_seek_mode_t
source · #[repr(C)]
pub enum pa_seek_mode_t {
Relative,
Absolute,
RelativeOnRead,
RelativeEnd,
}Variants
Relative
Seek relatively to the write index.
Absolute
Seek relatively to the start of the buffer queue.
RelativeOnRead
Seek relatively to the read index.
RelativeEnd
Seek relatively to the current end of the buffer queue.