Module libpulse_sys::volume [−][src]
Constants and routines for volume handling.
Structs
Constants
The maximum length of strings returned by pa_cvolume_snprint().
The maximum length of strings returned by pa_cvolume_snprint_verbose().
This floor value is used as minus infinity when using pa_sw_volume_to_dB() or
pa_sw_volume_from_dB().
The maximum length of strings returned by pa_sw_cvolume_snprint_dB().
The maximum length of strings returned by pa_sw_volume_snprint_dB().
Special ‘invalid’ volume.
Maximum valid volume we can store.
Muted (minimal valid) volume (0%, -inf dB).
Normal volume (100%, 0 dB).
The maximum length of strings returned by pa_volume_snprint().
The maximum length of strings returned by pa_volume_snprint_verbose().
Functions
Sets the volume of the first n channels to PA_VOLUME_MUTED.
Sets the volume of the first n channels to PA_VOLUME_NORM.
Type Definitions
The basic volume type.