Module libpulse_sys::xmalloc

source ·
Memory allocation functions.

Functions

Free allocated memory.
Allocate the specified number of bytes, just like malloc() does. However, in case of OOM, terminate.
Same as pa_xmalloc , but initialize allocated memory to 0.
Duplicate the specified memory block.
Allocate n new structures of the specified type.
Same as pa_xnew but set the memory to zero.
Same as pa_xnew but duplicate the specified data.
The combination of pa_xmalloc and realloc().
Reallocate n new structures of the specified type.
Duplicate the specified string, allocating memory with pa_xmalloc.
Duplicate the specified string, but truncate after l characters.