Module libpulse_sys::version
source · Expand description
Version constants and functions
The constants defined here follow those given in the C headers.
- They are typically updated only following a new major release of PA.
- They are not typically updated following a new minor release of PA. i.e. we may declare
version
12.0here, but remain compatible with all12.x, so long as PA itself continues to adhere to semantic versioning (i.e. no breaking changes in minor releases). - They are not the minimum compatible PA version. We have feature flags for providing backwards compatibility with a limited number of past major versions.
Currently:
- We primarily target PA version
12.x - We have backwards compatibility with PA version
11.x(and it is believed10.x) if thepa_encoding_from_stringfeature flag is disabled.
When feature flags are used for backwards compatibility, the versions defined here (as of
version 1.4) are adjusted to return the newest compatible major version.
The get_library_version function always obtains at runtime the version of the actual PA
library in use.
Enums
Used for indicating PA version compatibility support, which can vary depending upon feature
flags.
Constants
LINK_TARGET_VERSIONDeprecated
PA_MAJORDeprecated
PA_MICRODeprecated
PA_MINORDeprecated
The major and minor components of the newest version of the PulseAudio client library this
linking library is known to be compatible with.
The newest version of the PulseAudio client library this linking library is known to be
compatible with.
Functions
Returns indication of PA version compatibility support, depending upon feature flags used
pa_get_headers_versionDeprecated