Module libpulse_sys::volume
source · Expand description
Constants and routines for volume handling.
Structs
Constants
The maximum length of strings returned by
pa_cvolume_snprint. Please note that this value
can change with any release without warning and without being considered API or ABI breakage.
You should not use this definition anywhere where it might become part of an ABI.The maximum length of strings returned by
pa_cvolume_snprint_verbose. Please note that this
value can change with any release without warning and without being considered API or ABI
breakage. You should not use this definition anywhere where it might become part of an ABI.This floor value is used as minus infinity when using
pa_sw_volume_to_dB /
pa_sw_volume_from_dB.The maximum length of strings returned by
pa_sw_cvolume_snprint_dB. Please note that this
value can change with any release without warning and without being considered API or ABI
breakage. You should not use this definition anywhere where it might become part of an ABI.The maximum length of strings returned by
pa_sw_volume_snprint_dB. Please note that this
value can change with any release without warning and without being considered API or ABI
breakage. You should not use this definition anywhere where it might become part of an ABI.Special ‘invalid’ volume
Maximum valid volume we can store
Muted (minimal valid) volume (0%, -inf dB)
Normal volume (100%, 0 dB)
The maximum length of strings returned by
pa_volume_snprint.
Please note that this value can change with any release without warning and without being
considered API or ABI breakage. You should not use this definition anywhere where it might
become part of an ABI.The maximum length of strings returned by
pa_volume_snprint_verbose,
as per the underlying C function. Please note that this value can change with any release
without warning and without being considered API or ABI breakage. You should not use this
definition anywhere where it might become part of an ABI.Functions
Set the volume of the first n channels to
PA_VOLUME_MUTEDSet the volume of the first n channels to
PA_VOLUME_NORMType Definitions
The basic volume type